@@ -20,39 +20,39 @@
 #include <string>
 #include <fcntl.h>
 
-#include <qstring.h>
-#include <qsplitter.h>
-#include <qtimer.h>
-#include <qvaluelist.h>
-#include <qlayout.h>
-#include <qlineedit.h>
-#include <qbuffer.h>
-#include <qtoolbutton.h>
-#include <qtabwidget.h>
-#include <qlabel.h>
-#include <qtextedit.h>
-#include <qclipboard.h>
+#include <ntqstring.h>
+#include <ntqsplitter.h>
+#include <ntqtimer.h>
+#include <ntqvaluelist.h>
+#include <ntqlayout.h>
+#include <ntqlineedit.h>
+#include <ntqbuffer.h>
+#include <ntqtoolbutton.h>
+#include <ntqtabwidget.h>
+#include <ntqlabel.h>
+#include <ntqtextedit.h>
+#include <ntqclipboard.h>
 #include <kinstance.h>
-#include <kaction.h>
+#include <tdeaction.h>
 #include <kstdaction.h>
-#include <klistview.h>
+#include <tdelistview.h>
 #include <kdebug.h>
-#include <klocale.h>
-#include <kfiledialog.h>
-#include <ktempfile.h>
-#include <kconfigdialog.h>
+#include <tdelocale.h>
+#include <tdefiledialog.h>
+#include <tdetempfile.h>
+#include <tdeconfigdialog.h>
 #include <kstatusbar.h>
-#include <kglobalsettings.h>
-#include <kmessagebox.h>
+#include <tdeglobalsettings.h>
+#include <tdemessagebox.h>
 #include <kinputdialog.h>
-#include <kshortcut.h>
+#include <tdeshortcut.h>
 #include <kstandarddirs.h>
 #include <kiconloader.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kxmlguifactory.h>
-#include <kpopupmenu.h>
-#include <kio/netaccess.h>
-#include <kmainwindow.h>
+#include <tdepopupmenu.h>
+#include <tdeio/netaccess.h>
+#include <tdemainwindow.h>
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -70,13 +70,13 @@
 #include <encoderlatex.h>
 #include "kbibtex_part.h"
 
-const QString inPipeFilename = QDir::homeDirPath() + "/.kbibtex.in";
+const TQString inPipeFilename = TQDir::homeDirPath() + "/.kbibtex.in";
 
-KBibTeXPart::KBibTeXPart( QWidget *parentWidget, const char *widgetName,
-                          QObject *parent, const char *name )
+KBibTeXPart::KBibTeXPart( TQWidget *parentWidget, const char *widgetName,
+                          TQObject *parent, const char *name )
         : KParts::ReadWritePart( parent, name ), m_defInitCounter( 0 ), m_settingsDlg( NULL ), m_initializationDone( FALSE ), m_inPipe( NULL )
 {
-    m_mainWindow = dynamic_cast<KMainWindow*>( parent );
+    m_mainWindow = dynamic_cast<TDEMainWindow*>( parent );
     if ( m_mainWindow == NULL )
         kdDebug( ) << "Cannot determine main window" << endl;
 
@@ -101,7 +101,7 @@ KBibTeXPart::KBibTeXPart( QWidget *parentWidget, const char *widgetName,
     // read configuration
     readSettings();
 
-    QTimer::singleShot( 100, this, SLOT( slotDeferredInitialization() ) );
+    TQTimer::singleShot( 100, this, SLOT( slotDeferredInitialization() ) );
 }
 
 KBibTeXPart::~KBibTeXPart()
@@ -131,7 +131,7 @@ void KBibTeXPart::setReadWrite( bool rw )
 void KBibTeXPart::setModified( bool modified )
 {
     // get a handle on our Save action and make sure it is valid
-    KAction * save = actionCollection() ->action( KStdAction::stdName( KStdAction::Save ) );
+    TDEAction * save = actionCollection() ->action( KStdAction::stdName( KStdAction::Save ) );
 
     if ( save )
     {
@@ -151,7 +151,7 @@ bool KBibTeXPart::queryClose()
     if ( !isReadWrite() || !isModified() )
         return TRUE;
 
-    QString docName = url().fileName();
+    TQString docName = url().fileName();
     if ( docName.isEmpty() ) docName = i18n( "Untitled" );
 
     int res = KMessageBox::warningYesNoCancel( widget(),
@@ -223,13 +223,13 @@ bool KBibTeXPart::saveFile()
         tempBibFile.close();
         if ( success )
         {
-            QString usedFileName = m_file;
-            QFileInfo fi( usedFileName );
-            if ( !fi.readLink().isNull() && KMessageBox::questionYesNo( widget(), QString( i18n( "The selected filename \"%1\" is a symbolic link pointing to \"%2\".\nReplace the link with a new file or overwrite the existing file the link points to?" ) ).arg( usedFileName ).arg(KBibTeX::Settings::resolveLink( m_file, fi.readLink() ) ), i18n( "Symbolic Link" ), KGuiItem( i18n( "Replace link" ) ), KGuiItem( i18n( "Overwrite file the link points to" ) ) ) == KMessageBox::No )
+            TQString usedFileName = m_file;
+            TQFileInfo fi( usedFileName );
+            if ( !fi.readLink().isNull() && KMessageBox::questionYesNo( widget(), TQString( i18n( "The selected filename \"%1\" is a symbolic link pointing to \"%2\".\nReplace the link with a new file or overwrite the existing file the link points to?" ) ).arg( usedFileName ).arg(KBibTeX::Settings::resolveLink( m_file, fi.readLink() ) ), i18n( "Symbolic Link" ), KGuiItem( i18n( "Replace link" ) ), KGuiItem( i18n( "Overwrite file the link points to" ) ) ) == KMessageBox::No )
                 usedFileName = KBibTeX::Settings::resolveLink( m_file, fi.readLink() );
 
             m_documentWidget->dirWatch().stopScan();
-            success = KIO::NetAccess::file_copy( KURL( tempBibFile.name() ), KURL( usedFileName ), -1, true, false, widget() );
+            success = TDEIO::NetAccess::file_copy( KURL( tempBibFile.name() ), KURL( usedFileName ), -1, true, false, widget() );
             m_documentWidget->dirWatch().startScan();
         }
 
@@ -247,13 +247,13 @@ bool KBibTeXPart::saveAs()
     bool result = FALSE;
     KBibTeX::Settings * settings = KBibTeX::Settings::self( NULL );
 
-    QString startDir = ! url().isEmpty() ? url().url() : QDir::currentDirPath();
+    TQString startDir = ! url().isEmpty() ? url().url() : TQDir::currentDirPath();
     KURL saveURL = KFileDialog::getSaveURL( startDir, "*.bib|" + i18n( "BibTeX (*.bib)" ) + "\n*.ris|" + i18n( "Reference Manager (*.ris)" ) +
                                             ( settings->external_xml2bibAvailable ? "\n*.ref *.refer *.rfr *.txt|" + i18n( "EndNote (Refer format) (*.ref *.refer *.rfr *.txt)" ) + "\n*.isi *.cgi|" + i18n( "ISI Web of Knowledge (*.isi *.cgi)" ) : "" ) + "\n*.xml|" + ( settings->external_xml2bibAvailable ? i18n( "DocBook 5 or MODS (*.xml)" ) : i18n( "DocBook 5 (*.xml)" ) ), widget() );
 
     if ( saveURL.isValid() && !saveURL.isEmpty() )
     {
-        if ( KIO::NetAccess::exists( saveURL, FALSE, widget() ) && KMessageBox::warningContinueCancel( widget(), i18n( "A file named '%1' already exists. Are you sure you want to overwrite it?" ).arg( saveURL.filename() ), QString::null, i18n( "Overwrite" ) ) != KMessageBox::Continue )
+        if ( TDEIO::NetAccess::exists( saveURL, FALSE, widget() ) && KMessageBox::warningContinueCancel( widget(), i18n( "A file named '%1' already exists. Are you sure you want to overwrite it?" ).arg( saveURL.filename() ), TQString::null, i18n( "Overwrite" ) ) != KMessageBox::Continue )
             return result;
 
         if ( ReadWritePart::saveAs( saveURL ) )
@@ -269,14 +269,14 @@ bool KBibTeXPart::saveAs()
 void KBibTeXPart::slotFileExport()
 {
     KBibTeX::Settings * settings = KBibTeX::Settings::self( NULL );
-    QString startDir = ! url().isEmpty() ? url().url() : QDir::currentDirPath();
+    TQString startDir = ! url().isEmpty() ? url().url() : TQDir::currentDirPath();
     KURL exportURL = KFileDialog::getSaveURL( startDir, "*.pdf|" + i18n( "Portable Document File (*.pdf)" ) + "\n*.ps|" + i18n( "PostScript (*.ps)" ) + "\n*.ris|" + i18n( "Reference Manager (*.ris)" ) + ( settings->external_xml2bibAvailable ?  "\n*.ref *.refer *.rfr *.txt|" + i18n( "EndNote (Refer format) (*.ref *.refer *.rfr *.txt)" ) + "\n*.isi *.cgi|" + i18n( "ISI Web of Knowledge (*.isi *.cgi)" ) : "" ) +   "\n*.xml|" + ( settings->external_xml2bibAvailable ? i18n( "DocBook 5 or MODS (*.xml)" ) :  i18n( "DocBook 5 (*.xml)" ) ) + "\n*.html|" + i18n( "Hypertext Markup Langage (*.html)" ) + "\n*.rtf|" + i18n( "Rich Text Format (*.rtf)" ), widget() );
 
     if ( exportURL.isValid() && !exportURL.isEmpty() )
     {
-        if ( KIO::NetAccess::exists( exportURL, FALSE, widget() ) )
+        if ( TDEIO::NetAccess::exists( exportURL, FALSE, widget() ) )
         {
-            if ( KMessageBox::warningContinueCancel( widget(), i18n( "A file named '%1' already exists. Are you sure you want to overwrite it?" ).arg( exportURL.filename() ), QString::null, i18n( "Overwrite" ) ) != KMessageBox::Continue )
+            if ( KMessageBox::warningContinueCancel( widget(), i18n( "A file named '%1' already exists. Are you sure you want to overwrite it?" ).arg( exportURL.filename() ), TQString::null, i18n( "Overwrite" ) ) != KMessageBox::Continue )
                 return ;
 
             /** make backup if defined by the user */
@@ -301,9 +301,9 @@ void KBibTeXPart::slotFileExport()
             format = BibTeX::File::formatRIS;
         else if ( exportURL.fileName().endsWith( ".xml", FALSE ) )
         {
-            QStringList options = QStringList::split( '|', ( settings->external_xml2bibAvailable && settings->external_end2xmlAvailable ? "DocBook5|MODS|internal XML" : "DocBook5|internal XML" ) );
+            TQStringList options = TQStringList::split( '|', ( settings->external_xml2bibAvailable && settings->external_end2xmlAvailable ? "DocBook5|MODS|internal XML" : "DocBook5|internal XML" ) );
             bool ok = false;
-            QString answer = KInputDialog::getItem( i18n( "Choose file format" ), QString( i18n( "Choose file format of file '%1':" ) ).arg( exportURL.fileName() ), options, 0, false, &ok, widget() );
+            TQString answer = KInputDialog::getItem( i18n( "Choose file format" ), TQString( i18n( "Choose file format of file '%1':" ) ).arg( exportURL.fileName() ), options, 0, false, &ok, widget() );
             if ( ok && !answer.isNull() && answer == "DocBook5" )
                 format = BibTeX::File::formatDocBook5;
             else if ( ok && !answer.isNull() && answer == "MODS" )
@@ -315,9 +315,9 @@ void KBibTeXPart::slotFileExport()
             format = BibTeX::File::formatHTML;
         else
         {
-            QStringList options = QStringList::split( '|', ( settings->external_xml2bibAvailable && settings->external_end2xmlAvailable ? "BibTeX|EndNote|ISI|RIS" : "BibTeX|RIS" ) );
+            TQStringList options = TQStringList::split( '|', ( settings->external_xml2bibAvailable && settings->external_end2xmlAvailable ? "BibTeX|EndNote|ISI|RIS" : "BibTeX|RIS" ) );
             bool ok = false;
-            QString answer = KInputDialog::getItem( i18n( "Choose file format" ), QString( i18n( "Choose file format of file '%1':" ) ).arg( exportURL.fileName() ), options, 0, false, &ok, widget() );
+            TQString answer = KInputDialog::getItem( i18n( "Choose file format" ), TQString( i18n( "Choose file format of file '%1':" ) ).arg( exportURL.fileName() ), options, 0, false, &ok, widget() );
             if ( ok && !answer.isNull() && answer == "BibTeX" )
                 format = BibTeX::File::formatBibTeX;
             else if ( ok && !answer.isNull() && answer == "EndNote" )
@@ -328,23 +328,23 @@ void KBibTeXPart::slotFileExport()
                 format = BibTeX::File::formatRIS;
         }
 
-        QStringList errorLog;
+        TQStringList errorLog;
 
         bool error = !m_documentWidget->save( tempBibFile.file(), format, i18n( "Exporting" ), &errorLog ) ;
         if ( !error )
         {
             tempBibFile.close();
-            error = !KIO::NetAccess::file_copy( KURL( tempBibFile.name() ), exportURL, -1, TRUE, FALSE, widget() );
+            error = !TDEIO::NetAccess::file_copy( KURL( tempBibFile.name() ), exportURL, -1, TRUE, FALSE, widget() );
         }
 
         if ( error )
         {
-#if (KDE_VERSION_MINOR>=4) && (KDE_VERSION_MAJOR>=3)
+#if (TDE_VERSION_MINOR>=4) && (TDE_VERSION_MAJOR>=3)
             if ( !errorLog.empty() )
-                KMessageBox::errorList( widget(), QString( i18n( "File could not be exported in '%1'." ) ).arg( exportURL.prettyURL() ).append( i18n( "\n\nSee the following error log for details." ) ), errorLog, i18n( "Exporting failed" ) );
+                KMessageBox::errorList( widget(), TQString( i18n( "File could not be exported in '%1'." ) ).arg( exportURL.prettyURL() ).append( i18n( "\n\nSee the following error log for details." ) ), errorLog, i18n( "Exporting failed" ) );
             else
 #endif
-                KMessageBox::error( widget(), QString( i18n( "File could not be exported to '%1'." ) ).arg( exportURL.prettyURL() ), i18n( "Exporting failed" ) );
+                KMessageBox::error( widget(), TQString( i18n( "File could not be exported to '%1'." ) ).arg( exportURL.prettyURL() ), i18n( "Exporting failed" ) );
         }
 
     }
@@ -364,21 +364,21 @@ void KBibTeXPart::slotFileFindDups()
 void KBibTeXPart::slotFileMerge()
 {
     KBibTeX::Settings * settings = KBibTeX::Settings::self( NULL );
-    QString startDir = ! url().isEmpty() ? url().url() : QDir::currentDirPath();
-    KURL mergeURL = KFileDialog::getOpenURL( startDir, QString( "*.bib *.ris" ) +
+    TQString startDir = ! url().isEmpty() ? url().url() : TQDir::currentDirPath();
+    KURL mergeURL = KFileDialog::getOpenURL( startDir, TQString( "*.bib *.ris" ) +
                     ( settings->external_xml2bibAvailable && settings->external_end2xmlAvailable ? " *.xml *.ref *.refer *.rfr *.txt *.isi *.cgi" : "" ) + "|" + i18n( "Supported Bibliographies" ) + "\n*.bib|" + i18n( "BibTeX (*.bib)" ) + "\n*.ris|" + i18n( "Reference Manager (*.ris)" ) + ( settings->external_xml2bibAvailable && settings->external_end2xmlAvailable ? "\n*.ref *.refer *.rfr *.txt|" + i18n( "EndNote (Refer format) (*.ref *.refer *.rfr *.txt)" ) + "\n*.isi *.cgi|" + i18n( "ISI Web of Knowledge (*.isi *.cgi)" ) + "\n*.xml|" + i18n( "MODS or EndNote XML (*.xml)" ) : "" ) + "\n*|" + i18n( "All files (*.*)" )
                     , widget() );
 
     if ( !mergeURL.isValid() || mergeURL.isEmpty() )
         return;
 
-    QString extension = mergeURL.fileName();
+    TQString extension = mergeURL.fileName();
     int extPos = extension.find( '.' );
     if ( extPos < 0 )
         return;
     extension = extension.mid( extPos );
 
-    if ( !KIO::NetAccess::exists( mergeURL, TRUE, widget() ) )
+    if ( !TDEIO::NetAccess::exists( mergeURL, TRUE, widget() ) )
     {
         KMessageBox::error( widget(), i18n( "The given file could not be read, check if it exists or if it is readable for the current user." ) );
         return ;
@@ -386,7 +386,7 @@ void KBibTeXPart::slotFileMerge()
 
     KTempFile tempBibFile = KTempFile( locateLocal( "tmp", "bibmerge" ), extension );
     tempBibFile.setAutoDelete( TRUE );
-    bool error = !KIO::NetAccess::file_copy( mergeURL, KURL( tempBibFile.name() ),  -1, TRUE, FALSE, widget() );
+    bool error = !TDEIO::NetAccess::file_copy( mergeURL, KURL( tempBibFile.name() ),  -1, TRUE, FALSE, widget() );
 
     if ( !error )
         error = !m_documentWidget->open( tempBibFile.name(), TRUE );
@@ -408,11 +408,11 @@ void KBibTeXPart::slotPreferences()
         m_settingsDlg = new KBibTeX::SettingsDlg( widget(), "settings_dlg" );
 
     m_documentWidget->saveState();
-    if ( m_settingsDlg->exec() == QDialog::Accepted )
+    if ( m_settingsDlg->exec() == TQDialog::Accepted )
         m_documentWidget->restoreState();
 }
 
-void KBibTeXPart::setupGUI( QWidget *parentWidget, const char *name )
+void KBibTeXPart::setupGUI( TQWidget *parentWidget, const char *name )
 {
     m_documentWidget = new KBibTeX::DocumentWidget( !isReadWrite(), parentWidget, name );
 
@@ -427,11 +427,11 @@ void KBibTeXPart::setupActions()
         KStdAction::save( this, SLOT( save() ), actionCollection() ) ->setToolTip( i18n( "Save the current file" ) );
         KStdAction::saveAs( this, SLOT( slotFileSaveAs() ), actionCollection() ) ->setToolTip( i18n( "Save the current file under a new filename" ) );
     }
-    m_actionFileStatistics = new KAction( i18n( "Statistics..." ), CTRL + SHIFT + Key_I, this, SLOT( slotFileStatistics() ), actionCollection(), "file_statistics" );
-    m_actionFileFindDups = new KAction( i18n( "Find Duplicates..." ), CTRL + SHIFT + Key_D, this, SLOT( slotFileFindDups() ), actionCollection(), "file_finddups" );
-    m_actionFileExport = new KAction( i18n( "Export..." ), SmallIconSet( "goto" ), CTRL + Key_E, this, SLOT( slotFileExport() ), actionCollection(), "file_export" );
+    m_actionFileStatistics = new TDEAction( i18n( "Statistics..." ), CTRL + SHIFT + Key_I, this, SLOT( slotFileStatistics() ), actionCollection(), "file_statistics" );
+    m_actionFileFindDups = new TDEAction( i18n( "Find Duplicates..." ), CTRL + SHIFT + Key_D, this, SLOT( slotFileFindDups() ), actionCollection(), "file_finddups" );
+    m_actionFileExport = new TDEAction( i18n( "Export..." ), SmallIconSet( "goto" ), CTRL + Key_E, this, SLOT( slotFileExport() ), actionCollection(), "file_export" );
     m_actionFileExport->setToolTip( i18n( "Export to a different file format" ) );
-    m_actionFileMerge = new KAction( i18n( "Merge..." ), SmallIconSet( "reload" ), CTRL + Key_M, this, SLOT( slotFileMerge() ), actionCollection(), "file_merge" );
+    m_actionFileMerge = new TDEAction( i18n( "Merge..." ), SmallIconSet( "reload" ), CTRL + Key_M, this, SLOT( slotFileMerge() ), actionCollection(), "file_merge" );
     m_actionFileMerge->setToolTip( i18n( "Merge BibTeX entries from another file" ) );
 
     m_actionEditCut = KStdAction::cut( m_documentWidget, SLOT( cutElements() ), actionCollection() );
@@ -442,14 +442,14 @@ void KBibTeXPart::setupActions()
     m_actionEditCopy->setEnabled( FALSE );
     m_actionEditUndo =  KStdAction::undo( m_documentWidget, SLOT( undoEditor() ), actionCollection() );
     connect( m_documentWidget, SIGNAL( undoChanged( bool ) ), this, SLOT( slotUndoChanged( bool ) ) );
-    m_actionEditCopyRef = new KAction( i18n( "Copy &Reference" ), CTRL + SHIFT + Key_C, m_documentWidget, SLOT( copyRefElements() ), actionCollection(), "edit_copyref" );
+    m_actionEditCopyRef = new TDEAction( i18n( "Copy &Reference" ), CTRL + SHIFT + Key_C, m_documentWidget, SLOT( copyRefElements() ), actionCollection(), "edit_copyref" );
     m_actionEditCopyRef->setToolTip( i18n( "Copy a reference of the selected BibTeX elements to the clipboard" ) );
     m_actionEditCopyRef->setEnabled( FALSE );
     m_actionEditPaste = KStdAction::paste( m_documentWidget, SLOT( pasteElements() ), actionCollection() );
     m_actionEditPaste->setToolTip( i18n( "Paste BibTeX elements from the clipboard" ) );
     m_actionEditSelectAll = KStdAction::selectAll( m_documentWidget, SLOT( selectAll() ), actionCollection() );
     m_actionEditSelectAll->setToolTip( i18n( "Select all BibTeX elements" ) );
-    m_actionElementSendToLyX = new KAction( i18n( "Send Reference to &LyX" ), CTRL + SHIFT + Key_L, m_documentWidget, SLOT( sendSelectedToLyx() ), actionCollection(), "element_sendtolyx" );
+    m_actionElementSendToLyX = new TDEAction( i18n( "Send Reference to &LyX" ), CTRL + SHIFT + Key_L, m_documentWidget, SLOT( sendSelectedToLyx() ), actionCollection(), "element_sendtolyx" );
     m_actionElementSendToLyX->setToolTip( i18n( "Send a reference of the selected BibTeX elements to LyX" ) );
     m_actionElementSendToLyX->setEnabled( FALSE );
     m_actionEditFind = KStdAction::find( m_documentWidget, SLOT( find() ), actionCollection() );
@@ -459,66 +459,66 @@ void KBibTeXPart::setupActions()
     m_actionEditFind->setEnabled( FALSE );
     m_actionEditFindNext->setEnabled( FALSE );
 
-    m_actionSearchOnlineDatabases = new KAction( i18n( "Search Online Databases" ), SmallIconSet( "network" ), CTRL + SHIFT + Key_S, m_documentWidget, SLOT( onlineSearch() ), actionCollection(), "search_onlinedatabases" );
+    m_actionSearchOnlineDatabases = new TDEAction( i18n( "Search Online Databases" ), SmallIconSet( "network" ), CTRL + SHIFT + Key_S, m_documentWidget, SLOT( onlineSearch() ), actionCollection(), "search_onlinedatabases" );
     m_actionSearchOnlineDatabases->setToolTip( i18n( "Search online databases to import bibliography data" ) );
 
-    m_actionMenuSearchWebsites = new KActionMenu( i18n( "Search Document Online" ), actionCollection(), "search_document_online" );
+    m_actionMenuSearchWebsites = new TDEActionMenu( i18n( "Search Document Online" ), actionCollection(), "search_document_online" );
     m_actionMenuSearchWebsites->setToolTip( i18n( "Search websites for the selected BibTeX element" ) );
     connect( m_actionMenuSearchWebsites->popupMenu(), SIGNAL( activated( int ) ), this, SLOT( slotSearchWebsites( int ) ) );
     m_actionMenuSearchWebsites->setEnabled( FALSE );
 
-    m_actionViewShowColumns = new KActionMenu( i18n( "&Show Columns" ), actionCollection(), "view_showcolumns" );
+    m_actionViewShowColumns = new TDEActionMenu( i18n( "&Show Columns" ), actionCollection(), "view_showcolumns" );
     m_actionViewShowColumns->setToolTip( i18n( "Select columns to show in the main list" ) );
-    m_actionViewDocument = new KActionMenu( i18n( "View Document" ), actionCollection(), "view_document" );
+    m_actionViewDocument = new TDEActionMenu( i18n( "View Document" ), actionCollection(), "view_document" );
     m_actionViewDocument->setToolTip( i18n( "View the documents associated with this BibTeX entry" ) );
     m_actionViewDocument->setEnabled( FALSE );
-    m_actionViewFirstDocument = new KAction( i18n( "View Primary Document" ), 0, m_documentWidget, SLOT( slotViewFirstDocument() ), actionCollection(), "view_first_document" );
-    m_actionViewFirstDocument->setShortcut( Qt::Key_F4 );
-    m_actionViewDocumentOnlineRef = new KAction( i18n( "View Primary Online Reference" ), 0, m_documentWidget, SLOT( slotViewFirstDocumentsOnlineRef() ), actionCollection(), "view_first_documents_online_ref" );
-    m_actionViewDocumentOnlineRef->setShortcut( Qt::Key_F5 );
-    m_actionAssignKeywords = new KActionMenu( i18n( "Assign Keywords" ), actionCollection(), "assign_keywords" );
+    m_actionViewFirstDocument = new TDEAction( i18n( "View Primary Document" ), 0, m_documentWidget, SLOT( slotViewFirstDocument() ), actionCollection(), "view_first_document" );
+    m_actionViewFirstDocument->setShortcut( TQt::Key_F4 );
+    m_actionViewDocumentOnlineRef = new TDEAction( i18n( "View Primary Online Reference" ), 0, m_documentWidget, SLOT( slotViewFirstDocumentsOnlineRef() ), actionCollection(), "view_first_documents_online_ref" );
+    m_actionViewDocumentOnlineRef->setShortcut( TQt::Key_F5 );
+    m_actionAssignKeywords = new TDEActionMenu( i18n( "Assign Keywords" ), actionCollection(), "assign_keywords" );
     m_actionAssignKeywords->setToolTip( i18n( "Assign keywords to this entry" ) );
     m_actionAssignKeywords->setEnabled( FALSE );
-    m_actionNormalizeIds = new KAction( i18n( "Normalize Entry Ids" ), 0, m_documentWidget, SLOT( slotNormalizeIds() ), actionCollection( ), "normalize_ids" );
+    m_actionNormalizeIds = new TDEAction( i18n( "Normalize Entry Ids" ), 0, m_documentWidget, SLOT( slotNormalizeIds() ), actionCollection( ), "normalize_ids" );
     m_actionNormalizeIds->setToolTip( i18n( "Set entry ids as specified in the id suggestion settings" ) );
     m_actionNormalizeIds->setEnabled( FALSE );
 
     m_actionPreferences = KStdAction::preferences( this, SLOT( slotPreferences() ), actionCollection() );
     m_actionPreferences->setToolTip( i18n( "Configure KBibTeX" ) );
-    KAction *actionSourceEditor = new KAction( i18n( "Configure Source View..." ), 0, m_documentWidget, SLOT( configureEditor() ), actionCollection(), "options_configure_editor" );
+    TDEAction *actionSourceEditor = new TDEAction( i18n( "Configure Source View..." ), 0, m_documentWidget, SLOT( configureEditor() ), actionCollection(), "options_configure_editor" );
     actionSourceEditor ->setToolTip( i18n( "Configure the Source Editor" ) );
 
-    ( new KAction( i18n( "Article" ), 0, this, SLOT( slotNewElement() ), actionCollection(), "element_new_entry_article" ) ) ->setToolTip( i18n( "Add an article to the BibTeX file" ) );
-    ( new KAction( i18n( "Book" ), "element_new_entry_book", CTRL + Key_B, this, SLOT( slotNewElement() ), actionCollection(), "element_new_entry_book" ) ) ->setToolTip( i18n( "Add a book to the BibTeX file" ) );
-    ( new KAction( i18n( "Booklet" ), 0, this, SLOT( slotNewElement() ), actionCollection(), "element_new_entry_booklet" ) ) ->setToolTip( i18n( "Add a booklet to the BibTeX file" ) );
-    ( new KAction( i18n( "Electronic (IEEE)" ), 0, this, SLOT( slotNewElement() ), actionCollection(), "element_new_entry_electronic" ) ) ->setToolTip( i18n( "Add an electronic reference (IEEE) to the BibTeX file" ) );
-    ( new KAction( i18n( "InBook" ), 0, this, SLOT( slotNewElement() ), actionCollection(), "element_new_entry_inbook" ) ) ->setToolTip( i18n( "Add a part of a book to the BibTeX file" ) );
-    ( new KAction( i18n( "InCollection" ), 0, this, SLOT( slotNewElement() ), actionCollection(), "element_new_entry_incollection" ) ) ->setToolTip( i18n( "Add a publication which is part of some collection to the BibTeX file" ) );
-    ( new KAction( i18n( "InProceedings" ), "element_new_entry_inproceedings", CTRL + Key_I, this, SLOT( slotNewElement() ), actionCollection(), "element_new_entry_inproceedings" ) ) ->setToolTip( i18n( "Add a publication which is part of some proceedings to the BibTeX file" ) );
-    ( new KAction( i18n( "Manual" ), 0, this, SLOT( slotNewElement() ), actionCollection(), "element_new_entry_manual" ) ) ->setToolTip( i18n( "Add a manual to the BibTeX file" ) );
-    ( new KAction( i18n( "MastersThesis" ), 0, this, SLOT( slotNewElement() ), actionCollection(), "element_new_entry_mastersthesis" ) ) ->setToolTip( i18n( "Add a master or diploma thesis to the BibTeX file" ) );
-    ( new KAction( i18n( "Misc" ), 0, this, SLOT( slotNewElement() ), actionCollection(), "element_new_entry_misc" ) ) ->setToolTip( i18n( "Add a not specified document or reference to the BibTeX file" ) );
-    ( new KAction( i18n( "PhDThesis" ), 0, this, SLOT( slotNewElement() ), actionCollection(), "element_new_entry_phdthesis" ) ) ->setToolTip( i18n( "Add a PhD thesis to the BibTeX file" ) );
-    ( new KAction( i18n( "Proceedings" ), "element_new_entry_phdthesis" , CTRL + Key_P, this, SLOT( slotNewElement() ), actionCollection(), "element_new_entry_proceedings" ) ) ->setToolTip( i18n( "Add some proceedings to the BibTeX file" ) );
-    ( new KAction( i18n( "TechReport" ), 0, this, SLOT( slotNewElement() ), actionCollection(), "element_new_entry_techreport" ) ) ->setToolTip( i18n( "Add a technical report to the BibTeX file" ) );
-    ( new KAction( i18n( "Unpublished" ), 0, this, SLOT( slotNewElement() ), actionCollection(), "element_new_entry_unpublished" ) ) ->setToolTip( i18n( "Add an unpublished document to the BibTeX file" ) );
-    ( new KAction( i18n( "Preamble" ), 0, this, SLOT( slotNewElement() ), actionCollection(), "element_new_preamble" ) ) ->setToolTip( i18n( "Add a preamble to the BibTeX file" ) );
-    ( new KAction( i18n( "Comment" ), 0, this, SLOT( slotNewElement() ), actionCollection(), "element_new_comment" ) ) ->setToolTip( i18n( "Add a comment to the BibTeX file" ) );
-    ( new KAction( i18n( "Macro" ), 0, this, SLOT( slotNewElement() ), actionCollection(), "element_new_macro" ) ) ->setToolTip( i18n( "Add a macro to the BibTeX file" ) );
+    ( new TDEAction( i18n( "Article" ), 0, this, SLOT( slotNewElement() ), actionCollection(), "element_new_entry_article" ) ) ->setToolTip( i18n( "Add an article to the BibTeX file" ) );
+    ( new TDEAction( i18n( "Book" ), "element_new_entry_book", CTRL + Key_B, this, SLOT( slotNewElement() ), actionCollection(), "element_new_entry_book" ) ) ->setToolTip( i18n( "Add a book to the BibTeX file" ) );
+    ( new TDEAction( i18n( "Booklet" ), 0, this, SLOT( slotNewElement() ), actionCollection(), "element_new_entry_booklet" ) ) ->setToolTip( i18n( "Add a booklet to the BibTeX file" ) );
+    ( new TDEAction( i18n( "Electronic (IEEE)" ), 0, this, SLOT( slotNewElement() ), actionCollection(), "element_new_entry_electronic" ) ) ->setToolTip( i18n( "Add an electronic reference (IEEE) to the BibTeX file" ) );
+    ( new TDEAction( i18n( "InBook" ), 0, this, SLOT( slotNewElement() ), actionCollection(), "element_new_entry_inbook" ) ) ->setToolTip( i18n( "Add a part of a book to the BibTeX file" ) );
+    ( new TDEAction( i18n( "InCollection" ), 0, this, SLOT( slotNewElement() ), actionCollection(), "element_new_entry_incollection" ) ) ->setToolTip( i18n( "Add a publication which is part of some collection to the BibTeX file" ) );
+    ( new TDEAction( i18n( "InProceedings" ), "element_new_entry_inproceedings", CTRL + Key_I, this, SLOT( slotNewElement() ), actionCollection(), "element_new_entry_inproceedings" ) ) ->setToolTip( i18n( "Add a publication which is part of some proceedings to the BibTeX file" ) );
+    ( new TDEAction( i18n( "Manual" ), 0, this, SLOT( slotNewElement() ), actionCollection(), "element_new_entry_manual" ) ) ->setToolTip( i18n( "Add a manual to the BibTeX file" ) );
+    ( new TDEAction( i18n( "MastersThesis" ), 0, this, SLOT( slotNewElement() ), actionCollection(), "element_new_entry_mastersthesis" ) ) ->setToolTip( i18n( "Add a master or diploma thesis to the BibTeX file" ) );
+    ( new TDEAction( i18n( "Misc" ), 0, this, SLOT( slotNewElement() ), actionCollection(), "element_new_entry_misc" ) ) ->setToolTip( i18n( "Add a not specified document or reference to the BibTeX file" ) );
+    ( new TDEAction( i18n( "PhDThesis" ), 0, this, SLOT( slotNewElement() ), actionCollection(), "element_new_entry_phdthesis" ) ) ->setToolTip( i18n( "Add a PhD thesis to the BibTeX file" ) );
+    ( new TDEAction( i18n( "Proceedings" ), "element_new_entry_phdthesis" , CTRL + Key_P, this, SLOT( slotNewElement() ), actionCollection(), "element_new_entry_proceedings" ) ) ->setToolTip( i18n( "Add some proceedings to the BibTeX file" ) );
+    ( new TDEAction( i18n( "TechReport" ), 0, this, SLOT( slotNewElement() ), actionCollection(), "element_new_entry_techreport" ) ) ->setToolTip( i18n( "Add a technical report to the BibTeX file" ) );
+    ( new TDEAction( i18n( "Unpublished" ), 0, this, SLOT( slotNewElement() ), actionCollection(), "element_new_entry_unpublished" ) ) ->setToolTip( i18n( "Add an unpublished document to the BibTeX file" ) );
+    ( new TDEAction( i18n( "Preamble" ), 0, this, SLOT( slotNewElement() ), actionCollection(), "element_new_preamble" ) ) ->setToolTip( i18n( "Add a preamble to the BibTeX file" ) );
+    ( new TDEAction( i18n( "Comment" ), 0, this, SLOT( slotNewElement() ), actionCollection(), "element_new_comment" ) ) ->setToolTip( i18n( "Add a comment to the BibTeX file" ) );
+    ( new TDEAction( i18n( "Macro" ), 0, this, SLOT( slotNewElement() ), actionCollection(), "element_new_macro" ) ) ->setToolTip( i18n( "Add a macro to the BibTeX file" ) );
 
-    m_actionEditElement = new KAction( i18n( "&Edit" ), 0, m_documentWidget, SLOT( editElement() ), actionCollection(), "element_edit" );
+    m_actionEditElement = new TDEAction( i18n( "&Edit" ), 0, m_documentWidget, SLOT( editElement() ), actionCollection(), "element_edit" );
     m_actionEditElement->setToolTip( i18n( "Edit the selected BibTeX element" ) );
     m_actionEditElement->setEnabled( FALSE );
-    m_actionDeleteElement = new KAction( i18n( "&Delete" ), 0, m_documentWidget, SLOT( deleteElements() ), actionCollection(), "element_delete" );
+    m_actionDeleteElement = new TDEAction( i18n( "&Delete" ), 0, m_documentWidget, SLOT( deleteElements() ), actionCollection(), "element_delete" );
     m_actionDeleteElement->setToolTip( i18n( "Delete the selected BibTeX elements" ) );
     m_actionDeleteElement->setEnabled( FALSE );
 
-    m_actionShowComments = new KToggleAction( i18n( "Show &Comments" ), 0, this, SLOT( slotToggleShowSpecialElements() ), actionCollection(), "view_showcomments" );
+    m_actionShowComments = new TDEToggleAction( i18n( "Show &Comments" ), 0, this, SLOT( slotToggleShowSpecialElements() ), actionCollection(), "view_showcomments" );
     m_actionShowComments->setToolTip( i18n( "Show the comments of a BibTeX document" ) );
-    m_actionShowMacros = new KToggleAction( i18n( "Show &Macros" ), 0, this, SLOT( slotToggleShowSpecialElements() ), actionCollection(), "view_showmacros" );
+    m_actionShowMacros = new TDEToggleAction( i18n( "Show &Macros" ), 0, this, SLOT( slotToggleShowSpecialElements() ), actionCollection(), "view_showmacros" );
     m_actionShowMacros->setToolTip( i18n( "Show the macros of a BibTeX document" ) );
 
-    m_actionUseInPipe = new KToggleAction( i18n( "Accept input from other programs" ), 0, this , SLOT( slotUseInPipe() ), actionCollection(), "useinpipe" );
+    m_actionUseInPipe = new TDEToggleAction( i18n( "Accept input from other programs" ), 0, this , SLOT( slotUseInPipe() ), actionCollection(), "useinpipe" );
 
     connect( m_documentWidget, SIGNAL( listViewSelectionChanged( int ) ), this, SLOT( slotUpdateMenu( int ) ) );
 
@@ -527,14 +527,14 @@ void KBibTeXPart::setupActions()
         KStatusBar * statusBar = m_mainWindow->statusBar();
         if ( statusBar != NULL )
         {
-            connect( actionCollection(), SIGNAL( actionStatusText( const QString & ) ), statusBar, SLOT( message( const QString & ) ) );
+            connect( actionCollection(), SIGNAL( actionStatusText( const TQString & ) ), statusBar, SLOT( message( const TQString & ) ) );
             connect( actionCollection(), SIGNAL( clearStatusText() ), statusBar, SLOT( clear() ) );
         }
     }
 
     actionCollection() ->setHighlightingEnabled( true );
 
-    KActionMenu *acmElementNew = new KActionMenu( i18n( "&New" ), QIconSet( SmallIcon( "filenew" ) ), actionCollection(), "element_new" );
+    TDEActionMenu *acmElementNew = new TDEActionMenu( i18n( "&New" ), TQIconSet( SmallIcon( "document-new" ) ), actionCollection(), "element_new" );
     acmElementNew->setToolTip( i18n( "Add a new element to this BibTeX document" ) );
     acmElementNew->setEnabled( FALSE );
 }
@@ -543,10 +543,10 @@ bool KBibTeXPart::slotNewElement()
 {
     if ( isReadWrite() && sender() )
     {
-        QString elementType;
+        TQString elementType;
 
         if ( strncmp( sender() ->name(), "element_new_entry_", 18 ) == 0 )
-            elementType = QString( sender() ->name() + 18 );
+            elementType = TQString( sender() ->name() + 18 );
         else if ( strcmp( sender() ->name(), "element_new_comment" ) == 0 )
             elementType = "comment";
         else if ( strcmp( sender() ->name(), "element_new_macro" ) == 0 )
@@ -568,7 +568,7 @@ bool KBibTeXPart::slotNewElement()
 void KBibTeXPart::readSettings()
 {
     KBibTeX::Settings * settings = KBibTeX::Settings::self();
-    KConfig * config = KBibTeXPartFactory::instance() ->config();
+    TDEConfig * config = KBibTeXPartFactory::instance() ->config();
     settings->load( config );
 
     m_actionShowComments->setChecked( settings->editing_ShowComments );
@@ -583,7 +583,7 @@ void KBibTeXPart::writeSettings()
     KBibTeX::Settings * settings = KBibTeX::Settings::self();
     m_documentWidget->saveState();
 
-    KConfig * config = KBibTeXPartFactory::instance() ->config();
+    TDEConfig * config = KBibTeXPartFactory::instance() ->config();
 
     settings->editing_ShowComments = m_actionShowComments->isChecked();
     settings->editing_ShowMacros = m_actionShowMacros->isChecked();
@@ -617,9 +617,9 @@ void KBibTeXPart::slotUndoChanged( bool undoAvailable )
 
 void KBibTeXPart::slotUseInPipe()
 {
-    if ( m_inPipe == NULL && QFile::exists( inPipeFilename ) )
+    if ( m_inPipe == NULL && TQFile::exists( inPipeFilename ) )
     {
-        KMessageBox::error( widget(), QString( i18n( "Some other KBibTeX instance is using the pipe.\nIf this assumption is wrong, please delete '%1'." ) ).arg( inPipeFilename ), i18n( "Pipe already in use" ) );
+        KMessageBox::error( widget(), TQString( i18n( "Some other KBibTeX instance is using the pipe.\nIf this assumption is wrong, please delete '%1'." ) ).arg( inPipeFilename ), i18n( "Pipe already in use" ) );
     }
     else
     {
@@ -630,25 +630,25 @@ void KBibTeXPart::slotUseInPipe()
             m_inPipe->remove();
             delete m_inPipe;
             m_inPipe = NULL;
-            QFile::remove( inPipeFilename );
+            TQFile::remove( inPipeFilename );
         }
         else
         {
 // create pipe
             if ( ::mkfifo( inPipeFilename.latin1(), 0600 ) == 0 )
             {
-                m_inPipe = new QFile( inPipeFilename );
+                m_inPipe = new TQFile( inPipeFilename );
                 if ( !m_inPipe->open( IO_ReadOnly ) || fcntl( m_inPipe->handle(), F_SETFL, O_NONBLOCK ) < 0 )
                 {
                     m_inPipe->close();
                     m_inPipe = NULL;
                 }
                 if ( m_inPipe == NULL )
-                    QFile::remove( inPipeFilename );
+                    TQFile::remove( inPipeFilename );
             }
 
             if ( m_inPipe == NULL )
-                KMessageBox::error( widget(), QString( i18n( "Could not create pipe at '%1'." ) ).arg( inPipeFilename ), i18n( "Error creating pipe" ) );
+                KMessageBox::error( widget(), TQString( i18n( "Could not create pipe at '%1'." ) ).arg( inPipeFilename ), i18n( "Error creating pipe" ) );
         }
     }
 
@@ -695,17 +695,17 @@ void KBibTeXPart::slotDeferredInitialization()
             KMessageBox::sorry( widget(), i18n( "The KBibTeX part has problems to initialize itself. Only limited functionality will be available." ), i18n( "KBibTeX Part" ) );
             return ;
         }
-        QTimer::singleShot( 250, this, SLOT( slotDeferredInitialization() ) );
+        TQTimer::singleShot( 250, this, SLOT( slotDeferredInitialization() ) );
     }
 }
 
 // It's usually safe to leave the factory code alone.. with the
-// notable exception of the KAboutData data
-#include <kaboutdata.h>
-#include <klocale.h>
+// notable exception of the TDEAboutData data
+#include <tdeaboutdata.h>
+#include <tdelocale.h>
 
-KInstance* KBibTeXPartFactory::s_instance = 0L;
-KAboutData* KBibTeXPartFactory::s_about = 0L;
+TDEInstance* KBibTeXPartFactory::s_instance = 0L;
+TDEAboutData* KBibTeXPartFactory::s_about = 0L;
 
 KBibTeXPartFactory::KBibTeXPartFactory()
         : KParts::Factory()
@@ -721,27 +721,27 @@ KBibTeXPartFactory::~KBibTeXPartFactory()
     s_instance = 0L;
 }
 
-KParts::Part* KBibTeXPartFactory::createPartObject( QWidget *parentWidget, const char *widgetName,
-        QObject *parent, const char *name,
-        const char *classname, const QStringList & /* args */ )
+KParts::Part* KBibTeXPartFactory::createPartObject( TQWidget *parentWidget, const char *widgetName,
+        TQObject *parent, const char *name,
+        const char *classname, const TQStringList & /* args */ )
 {
     // Create an instance of our Part
     KBibTeXPart * obj = new KBibTeXPart( parentWidget, widgetName, parent, name );
 
     // See if we are to be read-write or not
-    if ( QCString( classname ) == "KParts::ReadOnlyPart" )
+    if ( TQCString( classname ) == "KParts::ReadOnlyPart" )
         obj->setReadWrite( false );
 
     return obj;
 }
 
-KInstance* KBibTeXPartFactory::instance()
+TDEInstance* KBibTeXPartFactory::instance()
 {
     if ( !s_instance )
     {
-        s_about = new KAboutData( "kbibtexpart", I18N_NOOP( "KBibTeXPart" ), "0.2.3.91" );
+        s_about = new TDEAboutData( "kbibtexpart", I18N_NOOP( "KBibTeXPart" ), "0.2.3.91" );
         s_about->addAuthor( "Thomas Fischer", 0, "fischer@unix-ag.uni-kl.de" );
-        s_instance = new KInstance( s_about );
+        s_instance = new TDEInstance( s_about );
     }
     return s_instance;
 }
