@@ -17,19 +17,19 @@
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
-#include <qfile.h>
-#include <qapplication.h>
-#include <qregexp.h>
-#include <qtimer.h>
-#include <qmap.h>
-#include <qspinbox.h>
-#include <kconfig.h>
+#include <ntqfile.h>
+#include <ntqapplication.h>
+#include <ntqregexp.h>
+#include <ntqtimer.h>
+#include <ntqmap.h>
+#include <ntqspinbox.h>
+#include <tdeconfig.h>
 
 #include <klineedit.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
-#include <kmessagebox.h>
-#include <kio/job.h>
+#include <tdemessagebox.h>
+#include <tdeio/job.h>
 
 #include <dcopref.h>
 
@@ -38,19 +38,19 @@
 
 namespace KBibTeX
 {
-    WebQueryGoogleScholarWidget::WebQueryGoogleScholarWidget( QWidget *parent, const char *name )
+    WebQueryGoogleScholarWidget::WebQueryGoogleScholarWidget( TQWidget *parent, const char *name )
             : WebQueryWidget( parent, name )
     {
         init();
 
         Settings *settings = Settings::self();
-        QString value = settings->getWebQueryDefault( "GoogleScholar" );
-        value = value == QString::null ? "" : value;
+        TQString value = settings->getWebQueryDefault( "GoogleScholar" );
+        value = value == TQString::null ? "" : value;
         lineEditQuery->setText( value );
         slotTextChanged( value, true );
     }
 
-    WebQueryGoogleScholar::WebQueryGoogleScholar( QWidget* parent )
+    WebQueryGoogleScholar::WebQueryGoogleScholar( TQWidget* parent )
             : WebQuery( parent ), m_transferJob( NULL ), m_transferJobBuffer( NULL )
     {
         m_importer = new BibTeX::FileImporterBibTeX( FALSE );
@@ -64,17 +64,17 @@ namespace KBibTeX
         delete m_importer;
     }
 
-    QString WebQueryGoogleScholar::title()
+    TQString WebQueryGoogleScholar::title()
     {
         return i18n( "Google Scholar" );
     }
 
-    QString WebQueryGoogleScholar::disclaimer()
+    TQString WebQueryGoogleScholar::disclaimer()
     {
         return i18n( "About Google Scholar" );
     }
 
-    QString WebQueryGoogleScholar::disclaimerURL()
+    TQString WebQueryGoogleScholar::disclaimerURL()
     {
         return "http://scholar.google.com/intl/en/scholar/about.html";
     }
@@ -110,11 +110,11 @@ namespace KBibTeX
         readAndChangeConfig();
 
         /** prepare HTTP request (buffer, signals, job) */
-        m_transferJobBuffer = new QBuffer();
+        m_transferJobBuffer = new TQBuffer();
         m_transferJobBuffer->open( IO_WriteOnly );
-        KIO::TransferJob* m_transferJob = KIO::get( KURL( "http://scholar.google.com/scholar_ncr" ), false, false );
-        connect( m_transferJob, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( slotData( KIO::Job *, const QByteArray & ) ) );
-        connect( m_transferJob, SIGNAL( result( KIO::Job * ) ), this, SLOT( slotFinishedStartpage( KIO::Job * ) ) );
+        TDEIO::TransferJob* m_transferJob = TDEIO::get( KURL( "http://scholar.google.com/scholar_ncr" ), false, false );
+        connect( m_transferJob, SIGNAL( data( TDEIO::Job *, const TQByteArray & ) ), this, SLOT( slotData( TDEIO::Job *, const TQByteArray & ) ) );
+        connect( m_transferJob, SIGNAL( result( TDEIO::Job * ) ), this, SLOT( slotFinishedStartpage( TDEIO::Job * ) ) );
     }
 
     void WebQueryGoogleScholar::cancelQuery()
@@ -125,7 +125,7 @@ namespace KBibTeX
         setEndSearch( WebQuery::statusError );
     }
 
-    void WebQueryGoogleScholar::slotFinishedStartpage( KIO::Job *job )
+    void WebQueryGoogleScholar::slotFinishedStartpage( TDEIO::Job *job )
     {
         /** close and delete buffer (content does not matter) */
         m_transferJobBuffer->close();
@@ -151,19 +151,19 @@ namespace KBibTeX
         enterNextStage();
 
         /** prepare next HTTP request for preferences page (buffer, signals, job) */
-        m_transferJobBuffer = new QBuffer();
+        m_transferJobBuffer = new TQBuffer();
         m_transferJobBuffer->open( IO_WriteOnly );
-        KIO::TransferJob* m_transferJob = KIO::get( KURL( "http://scholar.google.com/scholar_preferences?hl=en" ), false, false );
-        connect( m_transferJob, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( slotData( KIO::Job *, const QByteArray & ) ) );
-        connect( m_transferJob, SIGNAL( result( KIO::Job * ) ), this, SLOT( slotFinishedLoadingSettings( KIO::Job * ) ) );
+        TDEIO::TransferJob* m_transferJob = TDEIO::get( KURL( "http://scholar.google.com/scholar_preferences?hl=en" ), false, false );
+        connect( m_transferJob, SIGNAL( data( TDEIO::Job *, const TQByteArray & ) ), this, SLOT( slotData( TDEIO::Job *, const TQByteArray & ) ) );
+        connect( m_transferJob, SIGNAL( result( TDEIO::Job * ) ), this, SLOT( slotFinishedLoadingSettings( TDEIO::Job * ) ) );
 
     }
 
-    void WebQueryGoogleScholar::slotFinishedLoadingSettings( KIO::Job *job )
+    void WebQueryGoogleScholar::slotFinishedLoadingSettings( TDEIO::Job *job )
     {
         /** close and delete buffer (content does not matter) */
         m_transferJobBuffer->close();
-        QString htmlCode = textFromBuffer( m_transferJobBuffer );
+        TQString htmlCode = textFromBuffer( m_transferJobBuffer );
         delete m_transferJobBuffer;
 
         /** if aborted in the mean time, clean up everything */
@@ -186,27 +186,27 @@ namespace KBibTeX
         enterNextStage();
 
         /** parse html code to get form values */
-        QMap<QString, QString> keyValues = evalFormFields( htmlCode );
+        TQMap<TQString, TQString> keyValues = evalFormFields( htmlCode );
         /** set form values for BibTeX search */
         keyValues["scis"] = "yes";
         keyValues["scisf"] = "4";
         keyValues["submit"] = "Save+Preferences";
-        keyValues["num"] = QString::number( m_numberOfResults );
+        keyValues["num"] = TQString::number( m_numberOfResults );
 
         /** prepare next HTTP request to submit preferences (buffer, signals, job) */
         KURL nextUrl( formFieldsToUrl( "http://scholar.google.com/scholar_setprefs", keyValues ) );
-        m_transferJobBuffer = new QBuffer();
+        m_transferJobBuffer = new TQBuffer();
         m_transferJobBuffer->open( IO_WriteOnly );
-        KIO::TransferJob* m_transferJob = KIO::get( nextUrl, false, false );
-        connect( m_transferJob, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( slotData( KIO::Job *, const QByteArray & ) ) );
-        connect( m_transferJob, SIGNAL( result( KIO::Job * ) ), this, SLOT( slotFinishedSavingSettings( KIO::Job * ) ) );
+        TDEIO::TransferJob* m_transferJob = TDEIO::get( nextUrl, false, false );
+        connect( m_transferJob, SIGNAL( data( TDEIO::Job *, const TQByteArray & ) ), this, SLOT( slotData( TDEIO::Job *, const TQByteArray & ) ) );
+        connect( m_transferJob, SIGNAL( result( TDEIO::Job * ) ), this, SLOT( slotFinishedSavingSettings( TDEIO::Job * ) ) );
     }
 
-    void WebQueryGoogleScholar::slotFinishedSavingSettings( KIO::Job *job )
+    void WebQueryGoogleScholar::slotFinishedSavingSettings( TDEIO::Job *job )
     {
         /** close and delete buffer (content does not matter) */
         m_transferJobBuffer->close();
-        QString htmlCode = textFromBuffer( m_transferJobBuffer );
+        TQString htmlCode = textFromBuffer( m_transferJobBuffer );
         delete m_transferJobBuffer;
 
         /** if aborted in the mean time, clean up everything */
@@ -229,25 +229,25 @@ namespace KBibTeX
         enterNextStage();
 
         /** parse html code to get form values */
-        QMap<QString, QString> keyValues = evalFormFields( htmlCode );
+        TQMap<TQString, TQString> keyValues = evalFormFields( htmlCode );
         /** set form values for search */
         keyValues["q"] = m_searchTerm;
-        keyValues["num"] = QString::number( m_numberOfResults );
+        keyValues["num"] = TQString::number( m_numberOfResults );
 
         /** prepare next HTTP request for actual search (buffer, signals, job) */
         KURL nextUrl( formFieldsToUrl( "http://scholar.google.com/scholar", keyValues ) );
-        m_transferJobBuffer = new QBuffer();
+        m_transferJobBuffer = new TQBuffer();
         m_transferJobBuffer->open( IO_WriteOnly );
-        KIO::TransferJob* m_transferJob = KIO::get( nextUrl, false, false );
-        connect( m_transferJob, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( slotData( KIO::Job *, const QByteArray & ) ) );
-        connect( m_transferJob, SIGNAL( result( KIO::Job * ) ), this, SLOT( slotFinishedReceivingResultOverview( KIO::Job * ) ) );
+        TDEIO::TransferJob* m_transferJob = TDEIO::get( nextUrl, false, false );
+        connect( m_transferJob, SIGNAL( data( TDEIO::Job *, const TQByteArray & ) ), this, SLOT( slotData( TDEIO::Job *, const TQByteArray & ) ) );
+        connect( m_transferJob, SIGNAL( result( TDEIO::Job * ) ), this, SLOT( slotFinishedReceivingResultOverview( TDEIO::Job * ) ) );
     }
 
-    void WebQueryGoogleScholar::slotFinishedReceivingResultOverview( KIO::Job *job )
+    void WebQueryGoogleScholar::slotFinishedReceivingResultOverview( TDEIO::Job *job )
     {
         /** close and delete buffer (content does not matter) */
         m_transferJobBuffer->close();
-        QString htmlCode = textFromBuffer( m_transferJobBuffer );
+        TQString htmlCode = textFromBuffer( m_transferJobBuffer );
         delete m_transferJobBuffer;
 
         /** if aborted in the mean time, clean up everything */
@@ -270,7 +270,7 @@ namespace KBibTeX
         enterNextStage();
 
         /** find all links to BibTeX files in result page */
-        QRegExp reBibUrl( "/scholar.bib[^ \">]+" );
+        TQRegExp reBibUrl( "/scholar.bib[^ \">]+" );
         int pos = 0;
         while ( !m_aborted && ( pos = htmlCode.find( reBibUrl, pos + 1 ) ) > 0 )
         {
@@ -307,16 +307,16 @@ namespace KBibTeX
 
     void WebQueryGoogleScholar::readAndChangeConfig()
     {
-        KConfig cfg( "kcookiejarrc" );
+        TDEConfig cfg( "kcookiejarrc" );
         cfg.setGroup( "Cookie Policy" );
         m_originalEnableCookies = cfg.readBoolEntry( "Cookies", true );
         m_originalSessionCookies = cfg.readBoolEntry( "AcceptSessionCookies", true );
-        QStringList cookieSettingsList = QStringList::split( ',', cfg.readEntry( "CookieDomainAdvice", "" ) );
+        TQStringList cookieSettingsList = TQStringList::split( ',', cfg.readEntry( "CookieDomainAdvice", "" ) );
         m_originalCookieGlobalAdvice = cfg.readEntry( "CookieGlobalAdvice", "Accept" );
 
-        for ( QStringList::Iterator it = cookieSettingsList.begin(); it != cookieSettingsList.end(); ++it )
+        for ( TQStringList::Iterator it = cookieSettingsList.begin(); it != cookieSettingsList.end(); ++it )
         {
-            QStringList keyValue = QStringList::split( ':', *it );
+            TQStringList keyValue = TQStringList::split( ':', *it );
             if ( keyValue.size() == 2 )
             {
                 m_originalCookieMap[keyValue[0]] = keyValue[1];
@@ -327,9 +327,9 @@ namespace KBibTeX
         cfg.writeEntry( "CookieGlobalAdvice", "Accept" );
         cfg.writeEntry( "AcceptSessionCookies", true );
         cookieSettingsList.clear();
-        for ( QMap<QString, QString>::Iterator it = m_originalCookieMap.begin(); it != m_originalCookieMap.end(); ++it )
+        for ( TQMap<TQString, TQString>::Iterator it = m_originalCookieMap.begin(); it != m_originalCookieMap.end(); ++it )
         {
-            QString value = it.key().contains( ".google." ) ? "Accept" : it.data();
+            TQString value = it.key().contains( ".google." ) ? "Accept" : it.data();
             cookieSettingsList << it.key() + ":" + value;
         }
         cfg.writeEntry( "CookieDomainAdvice", cookieSettingsList.join( "," ) );
@@ -340,13 +340,13 @@ namespace KBibTeX
 
     void WebQueryGoogleScholar::restoreConfig()
     {
-        KConfig cfg( "kcookiejarrc" );
+        TDEConfig cfg( "kcookiejarrc" );
         cfg.setGroup( "Cookie Policy" );
         cfg.writeEntry( "CookieGlobalAdvice", m_originalCookieGlobalAdvice );
         cfg.writeEntry( "Cookies", m_originalEnableCookies );
         cfg.writeEntry( "AcceptSessionCookies", m_originalSessionCookies );
-        QStringList cookieSettingsList;
-        for ( QMap<QString, QString>::Iterator it = m_originalCookieMap.begin(); it != m_originalCookieMap.end(); ++it )
+        TQStringList cookieSettingsList;
+        for ( TQMap<TQString, TQString>::Iterator it = m_originalCookieMap.begin(); it != m_originalCookieMap.end(); ++it )
             cookieSettingsList << it.key() + ":" + it.data();
         cfg.writeEntry( "CookieDomainAdvice", cookieSettingsList.join( "," ) );
         cfg.sync();
@@ -357,33 +357,33 @@ namespace KBibTeX
             ( void )DCOPRef( "kded", "kcookiejar" ).send( "reloadPolicy" );
     }
 
-    QString WebQueryGoogleScholar::textFromBuffer( QBuffer *buffer )
+    TQString WebQueryGoogleScholar::textFromBuffer( TQBuffer *buffer )
     {
-        QString htmlCode = "";
+        TQString htmlCode = "";
         buffer->open( IO_ReadOnly );
-        QTextStream ts( buffer );
+        TQTextStream ts( buffer );
         while ( !ts.atEnd() )
             htmlCode.append( ts.readLine() );
         buffer->close();
         return htmlCode;
     }
 
-    QMap <QString, QString> WebQueryGoogleScholar::evalFormFields( const QString &htmlCode )
+    TQMap <TQString, TQString> WebQueryGoogleScholar::evalFormFields( const TQString &htmlCode )
     {
-        QMap<QString, QString> keyValues;
+        TQMap<TQString, TQString> keyValues;
 
-        QRegExp reInput( "<input[^>]+>" );
-        QRegExp reSplit( "[<>=\" ]+" );
+        TQRegExp reInput( "<input[^>]+>" );
+        TQRegExp reSplit( "[<>=\" ]+" );
         int pos = 0;
         while (( pos = htmlCode.find( reInput, pos + 1 ) ) > 5 )
         {
-            QStringList elements = QStringList::split( reSplit, reInput.cap( 0 ) );
+            TQStringList elements = TQStringList::split( reSplit, reInput.cap( 0 ) );
             bool checked = false;
             bool isCheckable = false;
             bool isSubmit = false;
-            QString key = QString::null;
-            QString value = QString::null;
-            for ( QStringList::Iterator it = elements.begin(); it != elements.end(); ++it )
+            TQString key = TQString::null;
+            TQString value = TQString::null;
+            for ( TQStringList::Iterator it = elements.begin(); it != elements.end(); ++it )
             {
                 if ( *it == "name" )
                 {
@@ -406,27 +406,27 @@ namespace KBibTeX
                     isSubmit = *it == "submit";
                 }
             }
-            if (( !isCheckable || checked ) && ( !isSubmit || value == "submit" ) && value != QString::null && key != QString::null )
+            if (( !isCheckable || checked ) && ( !isSubmit || value == "submit" ) && value != TQString::null && key != TQString::null )
             {
                 keyValues[key] = value;
             }
         }
 
-        QRegExp reSelect( "<select name=([^ >\"]+).*</select>" );
+        TQRegExp reSelect( "<select name=([^ >\"]+).*</select>" );
         reSelect.setMinimal( true );
-        QRegExp reOption( "<option[^>]+>" );
+        TQRegExp reOption( "<option[^>]+>" );
         int pos3 = 0;
         while (( pos3 = htmlCode.find( reSelect, pos3 + 1 ) ) > 5 )
         {
-            QString key = reSelect.cap( 1 );
-            QString sub = reSelect.cap( 0 );
+            TQString key = reSelect.cap( 1 );
+            TQString sub = reSelect.cap( 0 );
             int pos2 = 0;
             while (( pos2 = sub.find( reOption, pos2 + 1 ) ) > 5 )
             {
-                QStringList elements = QStringList::split( reSplit, reOption.cap( 0 ) );
+                TQStringList elements = TQStringList::split( reSplit, reOption.cap( 0 ) );
                 bool selected = false;
-                QString value = QString::null;
-                for ( QStringList::Iterator it = elements.begin(); it != elements.end(); ++it )
+                TQString value = TQString::null;
+                for ( TQStringList::Iterator it = elements.begin(); it != elements.end(); ++it )
                 {
                     if ( *it == "value" )
                     {
@@ -438,7 +438,7 @@ namespace KBibTeX
                     if ( *it == "selected" )
                         selected = true;
                 }
-                if ( selected && value != QString::null && key != QString::null )
+                if ( selected && value != TQString::null && key != TQString::null )
                 {
                     keyValues[key] = value;
                 }
@@ -448,11 +448,11 @@ namespace KBibTeX
         return keyValues;
     }
 
-    QString WebQueryGoogleScholar::formFieldsToUrl( const QString &prefix, const QMap<QString, QString> &keyValues )
+    TQString WebQueryGoogleScholar::formFieldsToUrl( const TQString &prefix, const TQMap<TQString, TQString> &keyValues )
     {
         bool first = true;
-        QString nextUrl = prefix;
-        for ( QMap<QString, QString>::ConstIterator it = keyValues.begin(); it != keyValues.end(); ++it )
+        TQString nextUrl = prefix;
+        for ( TQMap<TQString, TQString>::ConstIterator it = keyValues.begin(); it != keyValues.end(); ++it )
         {
             if ( first )
                 nextUrl.append( "?" );
